@@ -23,8 +23,8 @@ except ImportError:
 
 TEXT_ENDPOINT = "https://api.houndify.com/v1/text"
 VOICE_ENDPOINT = "https://api.houndify.com/v1/audio"
-TRANSCRIPTION_ENDPOINT = "https://api.houndify.com/v1/transcription"
-VERSION = "2.0.10"
+TRANSCRIPTION_ENDPOINT = "https://transcription.houndify.com/v1/transcription"
+VERSION = "2.0.12"
 
 
 class HoundifySDKError(Exception):
@@ -135,11 +135,6 @@ class _BaseHoundClient(object):
       if not self.saveQuery:
         headers["Hound-Extra-Options"] = '{"DoNotSave": ["all"], "DoNotLabel": true}'
 
-      if self.hostname == "speech-a-41.pnp.melodis.com:14005":
-        # when using CI server authproxy will not check domain access
-        # so we have to fake enabling the Transcription domain
-        headers["EnabledDomains"] = "0000000000000000000000000000040000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000010"
-
       return headers, requestInfoString
 
 
@@ -205,6 +200,8 @@ class HoundListener(object):
       pass
     def onEntityIdentification(self, entities, transcript):
       pass
+    def onTopicIdentification(self, topics, transcript):
+      pass
     def onPartialTranscriptTokens(self, transcript):
       """
       onPartialTranscriptTokens is fired when the server has a partial transcript.
@@ -466,7 +463,13 @@ class StreamingHoundClient(_BaseHoundClient):
               except:
                 pass
               try:
-                listener.onEntityIdentification(parsedMsg["EntityDetection"], parsedMsg["FinalPartialTranscriptTokens"])
+                if len(parsedMsg["EntityDetection"]) > 0:
+                  listener.onEntityIdentification(parsedMsg["EntityDetection"], parsedMsg["FinalPartialTranscriptTokens"])
+              except:
+                pass
+              try:
+                if len(parsedMsg["TopicIdentification"]) > 0:
+                  listener.onTopicIdentification(parsedMsg["TopicIdentification"], parsedMsg["FinalPartialTranscriptTokens"])
               except:
                 pass
               try:
@@ -545,6 +548,8 @@ class StreamingHoundClient(_BaseHoundClient):
               # in case something has really gone wrong
               time.sleep(0.1)
               continue
+        except Exception as e:
+          print(f"{e}")
 
         deadline = None
 
